[![downloads](https://img.shields.io/pypi/dm/pyratlib?color=blue&style=flat-square)](https://pypi.org/project/pyratlib/)
[![version](https://img.shields.io/pypi/v/pyratlib?color=blue&style=flat-square)](https://pypi.org/project/pyratlib/)
[![commit](https://img.shields.io/github/last-commit/pyratlib/pyrat?color=blue&style=flat-square)](https://github.com/pyratlib/pyrat/commits/main)
[![Open Source? Yes!](https://badgen.net/badge/Open%20Source%20%3F/Yes%21/blue?icon=github)](https://github.com/pyrat/pyratlib)
[![Stars](https://img.shields.io/github/stars/pyratlib/pyrat?style=social)](https://github.com/pyratlib/pyrat/stargazers)
<!-- [![Build Status](https://img.shields.io/appveyor/build/pyrat/pyratlib?style=flat-square)](https://travis-ci.com/pyrat/pyratlib) -->

<p align="center">
  <img width="500" height="600" src="https://github.com/pyratlib/pyrat/blob/main/docs/LOGO%20PYRAT.png">
</p>


# PyRat - Python in Rodent Analysis and Tracking
------------
PyRat is a user friendly library in python to analyze data from the DeepLabCut. Developed to help researchers unfamiliar with programming can perform animal behavior analysis more simpler.

# Installation
------------

The latest stable release is available on PyPi, and you can install it by saying
```
pip install pyratlib
```
Anaconda users can install using ``conda-forge``:
```
conda install -c conda-forge pyratlib
```

To build PyRat from source, say `python setup.py build`.
Then, to install PyRat, say `python setup.py install`.
If all went well, you should be able to execute the demo scripts under `examples/`
(OS X users should follow the installation guide given below).

Alternatively, you can download or clone the repository and use `pip` to handle dependencies:

```
unzip pyratlib.zip
pip install -e pyratlib
```
or
```
git clone https://github.com/pyratlib/pyrat.git
pip install -e pyratlib
```

By calling `pip list` you should see `pyrat` now as an installed package:
```
pyrat (0.x.x, /path/to/pyratlib)
```

# Development Team:
------------



- [Tulio Almeida]
- [Bruno Spinelli]
- [Ramon Hypolito]
- Maria Carolina Gonzalez
- [Abner Cardoso] 

<!-- Links -->
[Abner Cardoso]:https://github.com/abnr
[Bruno Spinelli]:https://github.com/brunospinelli
[Tulio Almeida]:https://github.com/tuliofalmeida
[Ramon Hypolito]:https://github.com/ramonhypolito


